@@ -1,9 +1,13 @@
 import asyncio
 import logging
-from typing import Awaitable, Callable, Dict, Generic, List, Set, TypeVar
+import re
+from typing import Awaitable, Callable, ClassVar, Dict, Generic, List, Set, TypeVar
+from urllib.parse import urlparse
 
 from nonebot.log import logger as _logger
 
+from .plugin_config import config as plugin_config
+
 _T = TypeVar("_T")
 LogListener = Callable[[_T], Awaitable[None]]
 
@@ -32,6 +36,29 @@ class LogStorage(Generic[_T]):
         return [self.logs[seq] for seq in sorted(self.logs, reverse=reverse)]
 
 
+class AccessLogFilter(logging.Filter):
+    log_match_re = re.compile(
+        r"\"(?P<method>\w+)\s+(?P<path>/\S+)\s(?P<protocol>\S+)\""
+    )
+    filterable_paths: ClassVar[Set[str]] = set()
+
+    def filter(self, record: logging.LogRecord) -> bool:
+        if plugin_config.MUTE_ACCESS_LOG is False:
+            return True
+
+        match = self.log_match_re.search(record.getMessage())
+        if not match:
+            return True
+
+        if urlparse(match.group("path")).path in self.filterable_paths:
+            record.levelno = 0
+            record.levelname = "TRACE"
+        return True
+
+
+logging.getLogger("uvicorn.access").addFilter(AccessLogFilter())
+
+
 STDOUT = _logger.level("STDOUT", no=logging.INFO)
 FATAL = _logger.level("FATAL", no=logging.FATAL)
 
