@@ -1,9 +1,9 @@
 from enum import IntEnum
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Literal, Optional, Union
 
 from nonebot import get_driver
 from nonebot.adapters.onebot.v11.config import Config as OnebotConfig
-from pydantic import BaseModel, Field, HttpUrl
+from pydantic import BaseModel, Field, FilePath, HttpUrl
 
 driver = get_driver()
 
@@ -45,6 +45,9 @@ class PluginConfig(BaseModel):
     PROCESS_KWARGS: Dict[str, Any] = Field(
         default_factory=dict, alias="gocq_process_kwargs"
     )
+    PROCESS_EXECUTABLE: Optional[Union[Literal["@PATH"], FilePath]] = Field(
+        None, alias="gocq_process_executable"
+    )
 
     WEBUI_USERNAME: Optional[str] = Field(None, alias="gocq_webui_username")
     WEBUI_PASSWORD: Optional[str] = Field(None, alias="gocq_webui_password")
@@ -53,6 +56,8 @@ class PluginConfig(BaseModel):
 
     TUNNEL_PORT: Optional[int] = Field(None, alias="gocq_tunnel_port")
 
+    MUTE_ACCESS_LOG: bool = Field(True, alias="gocq_mute_access_log")
+
 
 driver_config = driver.config
 onebot_config = OnebotConfig.parse_obj(driver_config.dict())
